@@ -20,7 +20,7 @@ use JSON;
 use URI::Template;
 use RDF::LDF::Error;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 {
    my $ua   = RDF::Trine->default_useragent;
    $ua->agent("RDF:::LDF/$RDF::LDF::VERSION " . $ua->_agent);
@@ -474,10 +474,12 @@ sub get_fragment {
     
     # JSON support in RDF::Trine isn't JSON-LD
     # Set the accept header quality parameter at a minimum for this format
-    RDF::Trine->default_useragent->default_header('Accept','text/turtle;q=1.0,application/turtle;q=1.0,application/x-turtle;q=1.0,application/rdf+xml;q=0.9,text/x-nquads;q=0.9,application/json;q=0.1,application/x-rdf+json;q=0.1');
+    my $ua = RDF::Trine->default_useragent;
+    $ua->default_header('Accept','text/turtle;q=1.0,application/turtle;q=1.0,application/x-turtle;q=1.0,application/rdf+xml;q=0.9,text/x-nquads;q=0.9,application/json;q=0.1,application/x-rdf+json;q=0.1');
 
     eval {
-        RDF::Trine::Parser->parse_url_into_model($url, $model);
+        # Need to explicitly set the useragent to keep the accept headers
+        RDF::Trine::Parser->parse_url_into_model($url, $model, useragent => $ua);
     };
     
     if ($@) {
